@@ -11,6 +11,7 @@ class TestGET(APITestCase):
     def setUp(self):
         self.factory = APIRequestFactory()
         self.client = APIClient()
+        self.ordered_fields = ['@context', '@type', '@id']
         LDListMixin.to_representation_cache.reset()
         LDPSerializer.to_representation_cache.reset()
         setattr(Circle._meta, 'depth', 0)
@@ -188,3 +189,19 @@ class TestGET(APITestCase):
         self.assertIn('ldp:contains', response.data)
         self.assertIn('permissions', response.data)
         self.assertIn('circle', response.data['ldp:contains'][0])
+
+    # test for checking fields ordering
+    def test_first_ordered_field(self):
+        self._set_up_circle_and_user()
+        response = self.client.get('/users/', content_type='application/ld+json')
+        fields_to_test = [
+            response.data.keys(),
+            response.data['ldp:contains'][1],
+            response.data['ldp:contains'][1]['circle_set']
+        ]
+
+        for test_fields in fields_to_test:
+            test_fields = list(test_fields)
+            o_f = [field for field in self.ordered_fields if field in test_fields]
+            self.assertEquals(o_f, test_fields[:len(o_f)])  
+    
\ No newline at end of file
